plone.app.event.ical.exporter — plone.app.event 1.0dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »

# plone.app.event.ical.exporter

class `plone.app.event.ical.exporter.` `EventsICal`(context, request)

  Returns events in iCal format.

class `plone.app.event.ical.exporter.` `ICalendarEventComponent`(context)

  Returns an icalendar object of the event.

`plone.app.event.ical.exporter.` `calendar_from_collection`(context)

  Container/Event adapter. Returns an icalendar.Calendar object from a Collection.

`plone.app.event.ical.exporter.` `calendar_from_container`(context)

  Container adapter. Returns an icalendar.Calendar object from a Containerish context like a Folder.

`plone.app.event.ical.exporter.` `calendar_from_event`(context)

  Event adapter. Returns an icalendar.Calendar object from an Event context.

`plone.app.event.ical.exporter.` `construct_icalendar`(context, events)

  Returns an icalendar.Calendar object.

  Parameters: | context – A content object, which is used for calendar details like Title and Description. Usually a container, collection or the event itself. events – The list of event objects, which are included in this calendar.

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »